@@ -63,6 +63,7 @@ void ipkg_init_options_array(const ipkg_conf_t *conf, ipkg_option_t **options)
 	  { "query-all", IPKG_OPT_TYPE_BOOL, &conf->query_all },
 	  { "verbose-wget", IPKG_OPT_TYPE_BOOL, &conf->verbose_wget },
 	  { "verbose_wget", IPKG_OPT_TYPE_BOOL, &conf->verbose_wget },
+	  { "verbosity", IPKG_OPT_TYPE_BOOL, &conf->verbosity },
 	  { NULL }
      };
 
@@ -607,6 +608,9 @@ int ipkg_conf_write_status_files(ipkg_conf_t *conf)
 		  || pkg->state_want == SW_PURGE)) {
 	       continue;
 	  }
+	  if (!pkg) {
+	    fprintf(stderr, "Null package\n");
+	  }
 	  if (pkg->dest == NULL) {
 	       fprintf(stderr, "%s: ERROR: Can't write status for "
 		       "package %s since it has a NULL dest\n",
@@ -622,17 +626,27 @@ int ipkg_conf_write_status_files(ipkg_conf_t *conf)
 
      for (iter = conf->pkg_dest_list.head; iter; iter = iter->next) {
 	  dest = iter->data;
-	  err = ferror(dest->status_file);
-	  fclose(dest->status_file);
-	  dest->status_file = NULL;
-	  if (!err) {
-	       file_move(dest->status_file_tmp_name, dest->status_file_name);
-	  } else {
-	       fprintf(stderr, "%s: ERROR: An error has occurred writing %s, "
-		       "retaining old %s\n", __FUNCTION__, 
-		       dest->status_file_tmp_name, dest->status_file_name);
+	  if (dest->status_file) {
+	       err = ferror(dest->status_file);
+	       fclose(dest->status_file);
+	       dest->status_file = NULL;
+	       if (!err) {
+		    file_move(dest->status_file_tmp_name, dest->status_file_name);
+	       } else {
+		    fprintf(stderr, "%s: ERROR: An error has occurred writing %s, "
+			    "retaining old %s\n", __FUNCTION__, 
+			    dest->status_file_tmp_name, dest->status_file_name);
+	       }
 	  }
      }
 
      return 0;
 }
+
+
+char *root_filename_alloc(ipkg_conf_t *conf, char *filename)
+{
+     char *root_filename;
+     sprintf_alloc(&root_filename, "%s%s", (conf->offline_root ? conf->offline_root : ""), filename);
+     return root_filename;
+}
